pub struct CircuitBreakerSet<R = CircuitBreaker>(/* private fields */);Implementations
Sourceimpl<R> CircuitBreakerSet<R>
impl<R> CircuitBreakerSet<R>
Sourcepub fn empty() -> Self
pub fn empty() -> Self
Returns an empty, no-op set with zero retained history.
Breakers can still be added later, but history-dependent breakers cannot trip until the set is configured with enough history capacity and samples have accumulated.
pub fn new(config: CircuitBreakerSetConfig) -> Self
pub fn set_manual_trip( &mut self, is_manually_tripped: bool, actor: AccountId, metadata: Option<Vec<u8>>, ) -> CircuitBreakerOutcome
pub fn remove( &mut self, breaker_id: u32, ) -> Result<CircuitBreakerOutcome, CircuitBreakerError>
pub fn sample_interval_ns(&self) -> Nanoseconds
pub fn accepted_history(&self) -> &RingBuffer<Observation>
pub fn observed_history(&self) -> &RingBuffer<Observation>
pub fn next_id(&self) -> u32
pub fn is_manually_tripped(&self) -> bool
pub fn breakers(&self) -> &BTreeMap<u32, CircuitBreakerState<R>>
pub fn breaker_count(&self) -> usize
pub fn is_blocking(&self) -> bool
pub fn blocking_reason(&self) -> Option<PriceBlockedReason>
Sourceimpl<R: CircuitBreakerRule> CircuitBreakerSet<R>
impl<R: CircuitBreakerRule> CircuitBreakerSet<R>
pub fn validate(&self) -> Result<(), CircuitBreakerSetParseError>
pub fn set_config( &mut self, config: CircuitBreakerSetConfig, ) -> Result<CircuitBreakerOutcome, CircuitBreakerError>
Sourceimpl CircuitBreakerSet<CircuitBreaker>
impl CircuitBreakerSet<CircuitBreaker>
pub fn add( &mut self, breaker_id: u32, breaker: CircuitBreaker, ) -> Result<CircuitBreakerOutcome, CircuitBreakerError>
pub fn set_enforced( &mut self, breaker_id: u32, is_enforced: bool, ) -> Result<CircuitBreakerOutcome, CircuitBreakerError>
pub fn rearm( &mut self, breaker_id: u32, armed_after_ns: Nanoseconds, ) -> Result<CircuitBreakerOutcome, CircuitBreakerError>
Sourceimpl<R: CircuitBreakerRule> CircuitBreakerSet<R>
impl<R: CircuitBreakerRule> CircuitBreakerSet<R>
pub fn try_accept_price( &mut self, price: Price, now: Nanoseconds, ) -> Result<CircuitBreakerOutcome<PriceAcceptance>, CircuitBreakerError>